@@ -8,7 +8,7 @@ import logging
 import collections.abc
 import codecs
 from collections import defaultdict
-from typing import Optional
+from typing import Optional, ClassVar, Type
 
 from jaraco.collections import FoldedCaseKeyedDict
 
@@ -242,6 +242,7 @@ class Part(Relational):
 
     content_type: Optional[str] = None
     rel_type: Optional[str] = None
+    encoding: str
 
     def __init__(self, package, name, **kwargs):
         # map(functools.partial(setattr, self), *kwargs.items())
@@ -498,6 +499,9 @@ class ContentType(object):
      application/xml, and a key which refers to the content type.
     """
 
+    Default: ClassVar[Type['ContentType']]
+    Override: ClassVar[Type['ContentType']]
+
     def __init__(self, name, key):
         self.name = name
         self.key = key
@@ -550,7 +554,7 @@ class Default(ContentType):
     key_name = 'Extension'
 
 
-ContentType.Default = Default  # type: ignore
+ContentType.Default = Default
 del Default
 
 
@@ -560,7 +564,7 @@ class Override(ContentType):
     key_name = 'PartName'
 
 
-ContentType.Override = Override  # type: ignore
+ContentType.Override = Override
 del Override
 
 # Construct E, a convient namespace for making elements in the OOXML
